function [eta_average] = Eulerian_transition_mobility(R,gamma,a,GS,t_fixed,t_trans,delta_t,lim,v_thresh)
% Eulerian_transition_mobility.m calculates the mobility of c-EIs
% R: (domain) circle radius
% gamma: vortex strength
% a: fixed vortex centre
% GS: grid size
% t_fixed: time spent on stationary states
% t_trans: time spent on transition
% delta_t: time interval in integration
% lim: circle radius around the fixed/moving vortex centre to be removed
% v_thresh: threshold velocity

tic

% moving vortex centre
a_t = @(m,t) ((-1)^(m+1))*a*(1-2*t/(t_trans/2));

% a period
t_total = t_fixed+t_trans;

% Initialise
n=round((t_trans/2)/delta_t+1);
delta_w_t = zeros(2,n);
velocity = zeros(2,n);
sum_final = 0;
num = 0;

for x = -R:GS:R
    for y = -R:GS:R
        % calculation only inside the circle
        if abs(x+1i*y) > R
            continue
        end
        
        for i=1:2 % 1 iteration 
            % index
            delta_w_ind = 1;
            k_v = 1;
            % transition
            for t_transition=0:delta_t:t_trans/2
                % exclude the region around the vortex centre
                if norm([x,y]-[a_t(i,t_transition),0]) <= lim
                    k_v = k_v + 1;
                    delta_w_ind = delta_w_ind + 1;
                    continue
                end
                
                % avoid moving vortex centre at domain centre
                if a_t(i,t_transition) == 0
                    t_tr=t_transition+delta_t/2;
                else
                    t_tr=t_transition;
                end
                
                if t_transition == 0
                    % velocity vector
                    vel1 = blinkingVortexVF(R,gamma,x,y,a_t(i,t_tr));
                    v1 = [real(vel1),imag(vel1)];
                  
                    % Singularity
                    if isnan(vel1)
                        k_v = k_v + 1;
                    else
                        velocity(i,k_v) = vel1;
                        k_v = k_v + 1;
                    end
                    
                    continue
                end
                
                % velocity vector
                vel2 = blinkingVortexVF(R,gamma,x,y,a_t(i,t_tr));
                v2 = [real(vel2),imag(vel2)];
                
                % Singularity
                if isnan(vel2)
                    k_v = k_v + 1;
                else
                    velocity(i,k_v) = vel2;
                    k_v = k_v + 1;
                end

                % relative rate of a velocity change
                delta_w=norm(v2-v1)/(norm(v2)+norm(v1));
                
                % Singularity
                if isnan(delta_w)
                    delta_w_ind = delta_w_ind + 1;
                else
                    delta_w_t(i,delta_w_ind) = delta_w;
                    delta_w_ind = delta_w_ind + 1;
                end
            end     
        end
        
        % integration
        sum_delta_w1 = sum(delta_w_t(1,2:end-1),'all');
        sum_delta_w2 = sum(delta_w_t(2,2:end-1),'all');
        sum_delta_w_col = sum(delta_w_t,1);
        
        sum_w_con = (sum_delta_w_col(1)+sum_delta_w_col(end)+2*(sum_delta_w1+sum_delta_w2))*delta_t/2;
        delta_w_t_average = sum_w_con/t_total;
        
        % v fast
        sum_vf1 = sum(velocity(1,2:end-1),'all');
        sum_vf2 = sum(velocity(2,2:end-1),'all');
        sum_vf_col = sum(velocity,1);
        
        sum_vf_dis = sum_vf_col(1)*t_fixed/2;
        sum_vf_con = (sum_vf_col(1)+sum_vf_col(end)+2*(sum_vf1+sum_vf2))*delta_t/2;
        
        vf_t_average = (sum_vf_dis+sum_vf_con)/t_total;
        v_fast = abs(vf_t_average);
        
        % v slow
        v_abs = abs(velocity);
        sum_vs1 = sum(v_abs(1,2:end-1),'all');
        sum_vs2 = sum(v_abs(2,2:end-1),'all');
        sum_vs_col = sum(v_abs,1);
        
        sum_vs_dis = sum_vs_col(1)*t_fixed/2;
        sum_vs_con = (sum_vs_col(1)+sum_vs_col(end)+2*(sum_vs1+sum_vs2))*delta_t/2;
        
        v_slow = (sum_vs_dis+sum_vs_con)/t_total;

        % v sum
        v_sum = (1-exp(-delta_w_t_average))*v_fast+exp(-delta_w_t_average)*v_slow;
        
        % count
        if v_sum >= v_thresh
            sum_final = sum_final + 1;
            num = num + 1;
        else
            num = num + 1;
        end
    end
end

eta_average = sum_final/num;

toc

beep
end