function [alpha_average] = Eulerian_transition_streamlineCrossing(R,gamma,a,GS,t_fixed,t_trans,delta_t)
% Eulerian_transition_streamlineCrossing.m calculates the streamline crossing of c-EIs
% R: (domain) circle radius
% gamma: vortex strength
% a: fixed vortex centre
% GS: grid size
% t_fixed: time spent on stationary states
% t_trans: time spent on transition
% delta_t: time interval in integration

tic

% moving vortex centre
a_t = @(m,t) ((-1)^(m+1))*a*(1-2*t/(t_trans/2));

% a period
t_total = t_fixed+t_trans;

% Initialise
n=round((t_trans/2)/delta_t+1);
theta_t = zeros(2,n);
theta_hat = zeros(2,n);
alpha_sum = 0;
alpha_num = 0;

for x = -R:GS:R
    for y = -R:GS:R
        % calculation only inside the circle
        if abs(x+1i*y) > R
            continue
        end
       
        % compute t average
        for i=1:2 % 1 iteration 
            theta_ind = 1; % index
            % transition
            for t_transition=0:delta_t:t_trans/2
                % avoid moving vortex centre at domain centre
                if a_t(i,t_transition) == 0
                    t_tr=t_transition+delta_t/2;
                else
                    t_tr=t_transition;
                end

                vel = blinkingVortexVF(R,gamma,x,y,a_t(i,t_tr)); % velocity vector
                theta = atan(imag(vel)/real(vel)); % angle with respect to x-axis
                
                % Singularity
                if isnan(theta)
                    theta_ind = theta_ind + 1;
                else
                    theta_t(i,theta_ind) = theta;
                    theta_ind = theta_ind + 1;
                end
            end
        end
        
        % integration
        sum_theta1 = sum(theta_t(1,2:end-1),'all');
        sum_theta2 = sum(theta_t(2,2:end-1),'all');
        sum_theta_col = sum(theta_t,1);
        
        sum_dis = sum_theta_col(1)*t_fixed/2;
        sum_con = (sum_theta_col(1)+sum_theta_col(end)+2*(sum_theta1+sum_theta2))*delta_t/2;
        
        theta_t_average = (sum_dis+sum_con)/t_total;
        
        % the range of theta hat
        for row =1:2
            for col=1:n
                if ((theta_t(row,col) - theta_t_average) > -pi/2) && ((theta_t(row,col) - theta_t_average) <= pi/2)
                    theta_hat(row,col) = theta_t(row,col) - theta_t_average;
                elseif ((theta_t(row,col) - theta_t_average) > pi/2) && ((theta_t(row,col) - theta_t_average) <= pi)
                    theta_hat(row,col) = pi - (theta_t(row,col) - theta_t_average);
                else
                    theta_hat(row,col) = - pi - (theta_t(row,col) - theta_t_average);
                end
            end
        end
        
        % integration
        theta_hat_square = theta_hat.^2;
        sum_theta_hat_square1 = sum(theta_hat_square(1,2:end-1),'all');
        sum_theta_hat_square2 = sum(theta_hat_square(2,2:end-1),'all');
        sum_theta_hat_square_col = sum(theta_hat_square,1);
        
        sum_dis_hat_square = sum_theta_hat_square_col(1)*t_fixed/2;
        sum_con_hat_square = (sum_theta_hat_square_col(1)+sum_theta_hat_square_col(end)+2*(sum_theta_hat_square1+sum_theta_hat_square2))*delta_t/2;
        
        theta_var = (sum_dis_hat_square+sum_con_hat_square)/t_total;
        theta_RMS = sqrt(theta_var);
        
        % the range of theta_RMS
        if (theta_RMS >= 0) && (theta_RMS <= pi/4)
            alpha = 2*theta_RMS;
        elseif (theta_RMS > pi/4) && (theta_RMS <= pi/2)
            alpha = 2*(pi/2 - theta_RMS);
        end
        
        alpha_sum = alpha_sum + alpha;
        alpha_num = alpha_num + 1;
        
    end
end

alpha_average = alpha_sum/alpha_num;

toc

beep
end