function [result] = solver_particle_distribution_BV(seedLeft,seedRight,R,gamma,a,iteration,t_fixed,t_trans)
% solver_particle_distribution_BV.m creates particlde distribution
% seedLeft: particles initially located on the left half circle (red)
% seedRight: particles initially located on the right half circle (green)
% R: radius of (domain) circle
% gamma: vortex strength
% a: fixed vortex centre
% iteration: the number of iterations
% t_fixed: time spent on stationary state
% t_trans: time spent on transition

tic

    function dydt = movingVortex(t,y)
        % moving vortex centre
        a_t = ((-1)^(i+1))*a*(1-2*t/(t_trans/2));
        
        % time integration scheme
        dydt = zeros(2,1);
        dydt(1) = -gamma/(2*pi)*(y(2)/((y(1)-a_t)^2+y(2)^2)-y(2)/((y(1)-R^2/a_t)^2+y(2)^2));
        dydt(2) = gamma/(2*pi)*((y(1)-a_t)/((y(1)-a_t)^2+y(2)^2)-(y(1)-R^2/a_t)/((y(1)-R^2/a_t)^2+y(2)^2));
    end

tspan=[1e-4 t_trans/2];
options = odeset('AbsTol',1e-7,'RelTol',1e-4);

% seed particles
zeta_left=seedLeft;
zeta_right=seedRight;
N_particle=length(zeta_left); % the number of particles on the half domain

% Initialise (temporary) particle position storage
x_t_left = zeros(1,length(N_particle));
y_t_left = zeros(1,length(N_particle));
x_t_right = zeros(1,length(N_particle));
y_t_right = zeros(1,length(N_particle));

for i=1:2*iteration
    %%%%%%%%%%%%%%%%%%%%%%%%%%%% Aref's mapping %%%%%%%%%%%%%%%%%%%%%%%%%%%
    if mod(i,2)==0
        zeta_left=-zeta_left;
        zeta_right=-zeta_right;
    end
    
    % red particles (initially at left half circle) 
    lambda_left=abs((zeta_left-a)./(zeta_left-R^2/a));
    rho_left=(lambda_left./(1-lambda_left.^2))*(R^2/a-a);
    zeta_c_left=(a-(lambda_left*R).^2/a)./(1-lambda_left.^2);
    
    phi_left=real(-1i*log((zeta_left-zeta_c_left)./rho_left));
    
    A_left=phi_left-2*lambda_left.*sin(phi_left)./(1+lambda_left.^2)+gamma*t_fixed*(1-lambda_left.^2)./(4*pi()*rho_left.^2.*(1+lambda_left.^2));
    
    % green particles (initially at right half circle)
    lambda_right=abs((zeta_right-a)./(zeta_right-R^2/a));
    rho_right=(lambda_right./(1-lambda_right.^2))*(R^2/a-a);
    zeta_c_right=(a-(lambda_right*R).^2/a)./(1-lambda_right.^2);
    
    phi_right=real(-1i*log((zeta_right-zeta_c_right)./rho_right));
    
    A_right=phi_right-2*lambda_right.*sin(phi_right)./(1+lambda_right.^2)+gamma*t_fixed*(1-lambda_right.^2)./(4*pi()*rho_right.^2.*(1+lambda_right.^2));
    
    for n=1:N_particle
        % red particles (initially at left half circle) 
        func=@(x) x-2*lambda_left(n).*sin(x)./(1+lambda_left(n).^2)-A_left(n);
        phi_left(n)=fzero(func,phi_left(n));
        % green particles (initially at right half circle)
        func=@(x) x-2*lambda_right(n).*sin(x)./(1+lambda_right(n).^2)-A_right(n);
        phi_right(n)=fzero(func,phi_right(n));
    end
    % red particles (initially at left half circle) 
    zeta_left=zeta_c_left+rho_left.*exp(1i*phi_left);
    % green particles (initially at right half circle)
    zeta_right=zeta_c_right+rho_right.*exp(1i*phi_right);
    
    if mod(i,2)==0
        zeta_left=-zeta_left;
        zeta_right=-zeta_right;
    end
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%% transition %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
    % prticle position
    x0_t_left = real(zeta_left);
    y0_t_left = imag(zeta_left);
    x0_t_right = real(zeta_right);
    y0_t_right = imag(zeta_right);
    
    for m=1:N_particle
        % initial conditions
        X0_t_left = [x0_t_left(m),y0_t_left(m)];
        X0_t_right = [x0_t_right(m),y0_t_right(m)];

        % time integration scheme
        [t,X_left]=ode23(@movingVortex,tspan,X0_t_left,options);
        [t,X_right]=ode23(@movingVortex,tspan,X0_t_right,options);
        
        % store positions after transition
        x_t_left(m) = X_left(end,1);
        y_t_left(m) = X_left(end,2);
        x_t_right(m) = X_right(end,1);
        y_t_right(m) = X_right(end,2);
    end
    
    % return to complex number
    zeta_left=x_t_left+1i*y_t_left;
    zeta_right=x_t_right+1i*y_t_right;  
end

result.left=zeta_left;
result.right=zeta_right;

toc

beep
end

